# The OCaml code is byte compiled, not native compiled, so there are no ELF
# objects in the binary RPM.
%global debug_package %{nil}

Name:           utop
Version:        2.15.0
Release:        %mkrel 1
Summary:        An improved toplevel for OCaml
License:        BSD-3-clause
Group:          Development/OCaml
URL:            https://github.com/ocaml-community/utop
Source0:        https://github.com/ocaml-community/utop/releases/download/%{version}/%{name}-%{version}.tar.gz
# Upstream patch to fix the version number
Patch:          %{name}-version.patch

BuildRequires:  ocaml >= 4.11.0
BuildRequires:  ocaml-alcotest-devel
BuildRequires:  ocaml-cppo >= 1.1.2
BuildRequires:  ocaml-dune >= 2.7
BuildRequires:  ocaml-findlib >= 1.7.2
BuildRequires:  ocaml-lambda-term-devel >= 3.1.0
BuildRequires:  ocaml-logs-devel
BuildRequires:  ocaml-lwt-devel
BuildRequires:  ocaml-lwt-react-devel
BuildRequires:  ocaml-react-devel >= 1.0.0
BuildRequires:  ocaml-xdg-devel >= 3.9.0
BuildRequires:  ocaml-zed-devel >= 3.2.0

# for utop.el
BuildRequires:  emacs
BuildRequires:  emacs-tuareg-mode

Provides:       ocaml-%{name}%{?_isa} =  %{version}-%{release}

%description
Utop is a universal toplevel for OCaml which can run in a terminal or
in emacs. It supports completion, colors, parenthesis matching, ...

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-findlib%{?_isa}
Requires:       ocaml-lambda-term-devel%{?_isa}
Requires:       ocaml-logs-devel%{?_isa}
Requires:       ocaml-zed-devel%{?_isa}
Provides:       ocaml-%{name}-devel%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%package -n emacs-utop
Summary:        Emacs front end for utop
BuildArch:      noarch
Requires:       emacs(bin) >= %{?_emacs_version}%{!?_emacs_version:0}
Requires:       emacs-tuareg-mode
Recommends:     emacs-company

%description -n emacs-utop
This package contains an Emacs front end for utop, an improved toplevel
for OCaml.

%prep
%autosetup -p1

%build
%dune_build

cd src/top
emacs -batch --no-init-file --no-site-file \
    --eval "(let ((backup-inhibited t)) (loaddefs-generate \".\" \"$PWD/utop-loaddefs.el\"))"
%_emacs_bytecompile utop.el
cd -

%install
%dune_install

# Install the Emacs interface
mkdir -p %{buildroot}%{_emacs_sitestartdir}
cp -p src/top/utop-loaddefs.* %{buildroot}%{_emacs_sitestartdir}
cp -p src/top/utop.elc %{buildroot}%{_emacs_sitelispdir}

%check
%dune_check

%files -f .ofiles
%license LICENSE
%doc README.md CHANGES.md

%files devel -f .ofiles-devel

%files -n emacs-utop
%{_emacs_sitelispdir}/%{name}.el*
%{_emacs_sitestartdir}/%{name}-loaddefs.el*


%changelog
* Sat Jun 21 2025 daviddavid <daviddavid> 2.15.0-1.mga10
+ Revision: 2193530
- new version: 2.15.0

* Sat Jan 14 2023 daviddavid <daviddavid> 2.9.2-1.mga9
+ Revision: 1932821
- new version: 2.9.2

* Sun Oct 16 2022 neoclust <neoclust> 2.9.1-2.mga9
+ Revision: 1897184
- Rebuild against new ocaml-base

* Fri May 20 2022 pterjan <pterjan> 2.9.1-1.mga9
+ Revision: 1859420
- Update to 2.9.1
- Rebuild for OCaml 4.14

* Thu Oct 14 2021 tv <tv> 2.8.0-1.mga9
+ Revision: 1751430
- Version 2.8.0
- New emacs-utop package to hold the Emacs interface

* Wed Mar 24 2021 tv <tv> 2.7.0-1.mga9
+ Revision: 1708708
- 2.7.0

* Fri Feb 28 2020 umeabot <umeabot> 2.4.3-3.mga8
+ Revision: 1551935
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 2.4.3-2.mga8
+ Revision: 1545189
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 tv <tv> 2.4.3-1.mga8
+ Revision: 1484144
- new release + reintroduce for ocaml-4.10

* Fri Feb 08 2019 daviddavid <daviddavid> 2.3.0-1.mga7
+ Revision: 1364154
- new version: 2.3.0

* Thu Oct 25 2018 daviddavid <daviddavid> 2.2.0-4.mga7
+ Revision: 1325507
- rebuild for new ocaml 4.07.1

* Fri Oct 12 2018 pterjan <pterjan> 2.2.0-3.mga7
+ Revision: 1319727
- Rebuild for new lwt

* Sun Sep 23 2018 umeabot <umeabot> 2.2.0-2.mga7
+ Revision: 1301555
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 daviddavid <daviddavid> 2.2.0-1.mga7
+ Revision: 1251250
- new version: 2.2.0

* Fri Jul 06 2018 daviddavid <daviddavid> 2.1.0-4.mga7
+ Revision: 1242139
- rebuild against current ocaml stack

* Fri Apr 27 2018 daviddavid <daviddavid> 2.1.0-3.mga7
+ Revision: 1222801
- rebuild for new ocaml-findlib 1.8.0

* Tue Mar 27 2018 daviddavid <daviddavid> 2.1.0-2.mga7
+ Revision: 1212744
- rebuild for new ocaml-react 1.2.1

* Fri Mar 16 2018 daviddavid <daviddavid> 2.1.0-1.mga7
+ Revision: 1209886
- new version: 2.1.0
- switch to the jbuilder build system
+ tv <tv>
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.18.1-2.mga6
+ Revision: 1056523
- Rebuild for fix in ocaml

* Wed Feb 17 2016 daviddavid <daviddavid> 1.18.1-1.mga6
+ Revision: 963683
- new version: 1.18.1
- update files list for devel subpackage
- add missing BR on ocaml-cppo-devel
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Oct 22 2015 daviddavid <daviddavid> 1.14-3.mga6
+ Revision: 894136
- add more docs to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 1.14-2.mga5
+ Revision: 742064
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 malo <malo> 1.14-1.mga5
+ Revision: 737476
- update to 1.14
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.5-2.mga4
+ Revision: 531719
- Mageia 4 Mass Rebuild

* Thu Aug 08 2013 blue_prawn <blue_prawn> 1.5-1.mga4
+ Revision: 464725
- updated to last version 1.5

* Mon Jan 14 2013 umeabot <umeabot> 1.2.1-2.mga3
+ Revision: 385200
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 20 2012 malo <malo> 1.2.1-1.mga3
+ Revision: 308602
- update file list
- update to 1.2.1
- update RPM group

* Tue Aug 07 2012 blue_prawn <blue_prawn> 1.2-1.mga3
+ Revision: 279772
- BuildRequires camlp4
- BuildRequires camlp4 and lambda-term
- imported package utop

